RAnEnExtra::mergeAnalogsByStations reads a vector of analog files, usually generated from anen_netcdf or anen_grib,
and then combines analogs by stations. It is assumed that analogs, Xs, and Ys exist in all files.
mergeAnalogsByStations( files, verbose = T, merge_forecasts = F, cores = 1, copy_vars = NULL )
| files | A vector of AnEn files |
|---|---|
| verbose | Whether to be verbose |
| merge_forecasts | Whether to merge |
| cores | The number of cores to use while reading files |
| copy_vars | The variable names to simply copy from the first file in the (sorted) list into the final AnEn list |
An AnEn.