R/organizeBinnedSpreadSkill.R
organizeBinnedSpreadSkill.RdRAnEnExtra::organizeBinnedSpreadSkill organize the verification results into a flat table format so that it is easy to plot with ggplot.
organizeBinnedSpreadSkill(results)
| results | The results from RAnEnExtra::verify. It should be a list. This function can only
parse verification generated by the metric |
|---|
A data frame