RAnEnExtra::organizeFLTs organize the verification results into a flat table format so that it is easy to plot with ggplot. Currently, this function only knows how to organize a portion of the verification metrics.
organizeFLTs(results, flts, parse_metrics = NULL, normalize = F)
| results | The results from RAnEnExtra::verify. It should be a list. |
|---|---|
| flts | The forecast lead times to be copied to the data frame. |
| parse_metrics | The metrics to organize into a data frame. Default to all supported metrics. |
| normalize | If |
a data frame or a data table