RAnEn::verifySpreadSkill calculates the binned spread skill correlation between ensemble spread and error.
verifyBinnedSpreadSkill( anen.ver, obs.ver, boot = F, R = 1000, intervals = 13, na.rm = T )
| anen.ver | A 4-dimensional array. This array is usually created from the |
|---|---|
| obs.ver | A 3-dimensional array. The dimensions should be |
| boot | Whether to use bootstrap. |
| R | The number of bootstrap replicates. Used by the function |
| intervals | The number of entries of days and lead times in each calculation iteration. |
| na.rm | Whether to remove NA values. |
Bootstrap confidence interval is defaulted to 0.95.
To change this, use options(RAnEnExtra_boot_conf = 0.9).