RAnEnExtra::verifySpreadSkill calculates the spread skill correlation between ensemble variance and squared error. Read details for caveats.
verifySpreadSkill( anen.ver, obs.ver, boot = F, R = 1000, na.rm = T, keep.cor = F )
| anen.ver | A 4-dimensional array. This array is usually created from the |
|---|---|
| obs.ver | A 3-dimensional array. The dimensions should be |
| boot | Whether to use bootstrap. |
| R | The number of bootstrap replicates. Used by the function |
| na.rm | Whether to remove NA values. |
| keep.cor | Whether to keep all spread and errors. |
Spread skill correlation without normalization or binning has several caveats during
its interpretation. Please make sure you have read through several materials before
applying this verification technique. Alternatively, RAnEn::verifyBinnedSpreadSkill is
an improved version of this function.
Bootstrap confidence interval is defaulted to 0.95.
To change this, use options(RAnEnExtra_boot_conf = 0.9).